===========
Ansible 2.9
===========

.. contents::
   :local:

Release Schedule
----------------

Expected
========

PRs must be raised well in advance of the dates below to have a chance of being included in this Ansible release.

.. note:: There is no Alpha phase in 2.9.

- 2019-08-29 Beta 1 **Feature freeze**
  No new functionality (including modules/plugins) to any code

- 2019-09-19 Release Candidate 1
- 2019-10-03 Release Candidate 2
- 2019-10-10 Release Candidate 3
- 2019-10-17 Release Candidate 4 (if needed)
- 2019-10-24 Release Candidate 5 (if needed)
- 2019-10-31 Release



Release Manager
---------------
TBD

Temporarily, Matt Davis (@nitzmahone) or Matt Clay (@mattclay) on IRC or github.

Planned work
============

See the `Ansible 2.9 Project Board <https://github.com/ansible/ansible/projects/34>`_
